==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/oauth2/l10n/nl.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Je client is niet geautoriseerd om te verbinden. Informeer de beheerder van je client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Je doorverwijzings-URL moet een volledige URL zijn, bijvoorbeeld: https://jouwdomein.com/pad",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Staat OAuth2 compatible authenticatie vanaf andere web applicaties toe.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "De OAuth2 app laat beheerders de ingebouwde inlog-workflow configureren om ook OAuth2 compatible authenticatie vanaf andere web applicaties mogelijk te maken.",
    "OAuth 2.0 clients" : "OAuth 2.0 Clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 staat externe services toe om toegang te vragen bij {instanceName}.",
    "Name" : "Naam",
    "Redirection URI" : "Omeiding URI",
    "Client Identifier" : "Client identificatie",
    "Secret key" : "Geheime sleutel",
    "Delete client" : "Client verwijderen",
    "Make sure you store the secret key, it cannot be recovered." : "Zorg ervoor dat je de geheime sleutel opslaat, deze kan niet worden hersteld.",
    "Add client" : "Voeg client toe",
    "Add" : "Toevoegen",
    "Show client secret" : "Geheime sleutel van cliënt weergeven",
    "Hide client secret" : "Geheime sleutel van cliënt verbergen",
    "Delete" : "verwijderen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/oauth2/l10n/nl.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Je client is niet geautoriseerd om te verbinden. Informeer de beheerder van je client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Je doorverwijzings-URL moet een volledige URL zijn, bijvoorbeeld: https://jouwdomein.com/pad",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Staat OAuth2 compatible authenticatie vanaf andere web applicaties toe.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "De OAuth2 app laat beheerders de ingebouwde inlog-workflow configureren om ook OAuth2 compatible authenticatie vanaf andere web applicaties mogelijk te maken.",
    "Secret key" : "Geheime sleutel",
    "Delete" : "verwijderen",
    "OAuth 2.0 clients" : "OAuth 2.0 Clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 staat externe services toe om toegang te vragen bij {instanceName}.",
    "Name" : "Naam",
    "Redirection URI" : "Omeiding URI",
    "Delete client" : "Client verwijderen",
    "Make sure you store the secret key, it cannot be recovered." : "Zorg ervoor dat je de geheime sleutel opslaat, deze kan niet worden hersteld.",
    "Add client" : "Voeg client toe",
    "Add" : "Toevoegen",
    "Client Identifier" : "Client identificatie",
    "Show client secret" : "Geheime sleutel van cliënt weergeven",
    "Hide client secret" : "Geheime sleutel van cliënt verbergen"
},
"nplurals=2; plural=(n != 1);");
